@@ -29,6 +29,16 @@ try_parse = function(code, silent = TRUE) {
   !inherits(try(parse(text = code), silent = silent), 'try-error')
 }
 
+parse_source = function(lines) {
+  # adapted from evaluate
+  src = srcfilecopy('<text>', lines = '')
+  if (length(grep('\n', lines))) lines = unlist(strsplit(
+    sub('$', '\n', as.character(lines)), '\n'
+  ))
+  src$lines = lines
+  parse(text = lines, srcfile = src)
+}
+
 # borrowed from knitr
 
 # escape backslashes and {} for the alltt package
